@@ -3,10 +3,10 @@
 #' This function returns a ggplot object with an annotated plot of a
 #' cps_spct object.
 #'
-#' @note Note that scales are expanded so as to make space for the annotations.
-#'   The object returned is a ggplot object, and can be further manipulated.
-#'   When spct has more than one column with spectral data, each of these
-#'   columns is normalized individually.
+#' Note that scales are expanded so as to make space for the annotations. The
+#' object returned is a ggplot object, and can be further manipulated. When spct
+#' has more than one column with spectral data, each of these columns is
+#' normalized individually.
 #'
 #' @param spct a cps_spct object
 #' @param w.band list of waveband objects
@@ -24,14 +24,15 @@
 #'   as arguments. A list with \code{numeric} and/or \code{character} values is
 #'   also accepted.
 #' @param annotations a character vector
-#' @param norm numeric normalization wavelength (nm) or character string "max"
-#'   for normalization at the wavelength of highest peak.
 #' @param text.size numeric size of text in the plot decorations.
 #' @param idfactor character Name of an index column in data holding a
 #'   \code{factor} with each spectrum in a long-form multispectrum object
 #'   corresponding to a distinct spectrum. If \code{idfactor=NULL} the name of
 #'   the factor is retrieved from metadata or if no metadata found, the
 #'   default "spct.idx" is tried.
+#' @param facets logical or integer Indicating if facets are to be created for
+#'   the levels of \code{idfactor} when \code{spct} contain multiple spectra in
+#'   long form.
 #' @param ylim numeric y axis limits,
 #' @param na.rm logical.
 #' @param ... currently ignored.
@@ -48,14 +49,15 @@ cps_plot <- function(spct,
                      span,
                      wls.target,
                      annotations,
-                     norm,
                      text.size,
                      idfactor,
+                     facets,
                      ylim,
+                     object.label,
                      na.rm,
                      ...) {
   if (!is.cps_spct(spct)) {
-    stop("cps_plot() can only plot response_spct objects.")
+    stop("cps_plot() can only plot cps_spct objects.")
   }
   if (is.null(ylim) || !is.numeric(ylim)) {
     ylim <- rep(NA_real_, 2L)
@@ -68,68 +70,62 @@ cps_plot <- function(spct,
   }
   cps.cols <- names(spct)[grep("^cps", names(spct))]
   num.cps.cols <- length(cps.cols)
-  stopifnot(num.cps.cols == 1L || getMultipleWl(spct) <= 1L)
-  #  other.cols <- setdiff(names(x), cps.cols)
-  if (is.null(norm)) {
-    # we will use the original data
-    scale.factor <- 1
-  } else {
-    for (col in cps.cols) {
-      if (is.character(norm)) {
-        if (norm %in% c("max", "maximum")) {
-          idx <- which.max(spct[[col]])
-        } else {
-          warning("Invalid character '", norm, "'value in 'norm'")
-          return(ggplot())
-        }
-        scale.factor <- 1 / as.numeric(spct[idx, col])
-        norm <- as.numeric(spct[idx, "w.length"])
-      } else if (is.numeric(norm) && norm >= min(spct) && norm <= max(spct)) {
-        scale.factor <- 1 / interpolate_spct(spct, norm)[[col]]
-      } else if (is.numeric(norm)) {
-        warning("'norm = ", norm, "' value outside spectral data range of ",
-                round(min(spct)), " to ", round(max(spct)), " (nm)")
-        return(ggplot())
-      } else {
-        stop("'norm' should be numeric or character")
-      }
-      spct[[col]] <-  spct[[col]] * scale.factor
-    }
+  # if individual spectra have multiple columns we force facets
+  if (!as.logical(facets) && num.cps.cols > 1L && getMultipleWl(spct) > 1L) {
+    message("Usings facets because spectra contain multiple scans.")
+    facets <- TRUE
   }
 
-  if (scale.factor != 1) {
-    if (!pc.out) {
-      multiplier.label <- "rel."
-      #      scale.factor <- 1 * scale.factor
-    } else {
-      multiplier.label <- "%"
-      scale.factor <- 100 * scale.factor
-    }
-    if (is.numeric(norm)) {
-      norm <- signif(norm, digits = 4)
+  if (is_scaled(spct)) {
+    if (pc.out) {
+      warning("Percent scale supported only for normalized cps_spct objects.")
+      pc.out <- FALSE
     }
     s.cps.label <-
-      bquote(Pixel~~response~~rate~~N( italic(lambda) )/N( .(norm))~~(.(multiplier.label)))
+      expression(Pixel~~response~~rate~~k %*% N[lambda]~~("rel."))
+    cps.label <- ""
+  } else if (is_normalized(spct)) {
+    norm.ls <- photobiology::getNormalization(spct)
+    norm.wl <- round(norm.ls[["norm.wl"]], digits = 1)
+    if (pc.out) {
+      multiplier.label <- "%"
+    } else {
+      multiplier.label <- "/1"
+    }
+    s.cps.label <-
+      bquote(Pixel~~response~~rate~~N[lambda]/N[lambda == .(norm.wl)]~~(.(multiplier.label)))
     cps.label <- ""
   } else {
+    if (pc.out) {
+      warning("Percent scale supported only for normalized cps_spct objects.")
+      pc.out <- FALSE
+    }
     s.cps.label <-
-      expression(Pixel~~response~~rate~~N(lambda)~~(counts~~s^{-1}))
+      expression(Pixel~~response~~rate~~N[lambda]~~(counts~~s^{-1}))
     cps.label <- ""
   }
 
   if (num.cps.cols > 1L) {
-    # remove raw_spct class before melting as it invalidates expectations
+    # remove cps_spct class before melting as it invalidates expectations
     rmDerivedSpct(spct)
-    spct <- tidyr::gather_(data = spct,
-                           key_col = "scan",
-                           value_col = "cps",
-                           gather_cols = cps.cols)
-    setCpsSpct(spct, multiple.wl = length(cps.cols))
+    spct <- tidyr::pivot_longer(data = spct,
+                                cols = tidyselect::all_of(cps.cols),
+                                names_to = "scan",
+                                values_to = "cps")
+    setCpsSpct(spct, multiple.wl = NULL) # guessed from data
     plot <- ggplot(spct, aes_(x = ~w.length, y = ~cps, linetype = ~scan))
+    temp <- find_idfactor(spct = spct,
+                          idfactor = idfactor,
+                          facets = facets,
+                          annotations = annotations,
+                          num.columns = num.cps.cols)
+    plot <- plot + temp$ggplot_comp
+    annotations <- temp$annotations
   } else {
     plot <- ggplot(spct, aes_(x = ~w.length, y = ~cps))
     temp <- find_idfactor(spct = spct,
                           idfactor = idfactor,
+                          facets = facets,
                           annotations = annotations)
     plot <- plot + temp$ggplot_comp
     annotations <- temp$annotations
@@ -173,6 +169,12 @@ cps_plot <- function(spct,
                             text.size = text.size,
                             na.rm = TRUE)
 
+  if (abs(y.max - 1) < 0.02 && abs(y.min) < 0.02) {
+    y.breaks <- c(0, 0.25, 0.5, 0.75, 1)
+  } else {
+    y.breaks <- scales::pretty_breaks(n = 5)
+  }
+
   if (!is.null(annotations) &&
       length(intersect(c("boxes", "segments", "labels", "summaries", "colour.guide", "reserve.space"), annotations)) > 0L) {
     y.limits <- c(y.min, y.max * 1.25)
@@ -182,7 +184,16 @@ cps_plot <- function(spct,
     x.limits <- range(spct)
   }
 
-  plot <- plot + scale_y_continuous(limits = y.limits)
+  if (pc.out) {
+    plot <- plot +
+      scale_y_continuous(labels = scales::percent,
+                         breaks = y.breaks,
+                         limits = y.limits)
+  } else {
+    plot <-
+      plot + scale_y_continuous(breaks = y.breaks,
+                                limits = y.limits)
+  }
   plot + scale_x_continuous(limits = x.limits, breaks = scales::pretty_breaks(n = 7))
 
 }
@@ -192,8 +203,11 @@ cps_plot <- function(spct,
 #' This function returns a ggplot object with an annotated plot of a
 #' response_spct object.
 #'
-#' @note Note that scales are expanded so as to make space for the annotations.
-#'   The object returned is a ggplot objects, and can be further manipulated.
+#' Note that scales are expanded so as to make space for the annotations. The
+#' object returned is a ggplot objects, and can be further manipulated.
+#'
+#' @inheritSection decoration Plot Annotations
+#' @inheritSection autotitle Title Annotations
 #'
 #' @param object a cps_spct object.
 #' @param ... in the case of collections of spectra, additional arguments passed
@@ -202,7 +216,8 @@ cps_plot <- function(spct,
 #' @param range an R object on which range() returns a vector of length 2, with
 #'   min annd max wavelengths (nm).
 #' @param unit.out character IGNORED.
-#' @param pc.out logical, if TRUE use percents instead of fraction of one
+#' @param pc.out logical, if TRUE use percent instead of fraction of one for
+#'   normalized spectral data.
 #' @param label.qty character string giving the type of summary quantity to use
 #'   for labels, one of "mean", "total", "contribution", and "relative".
 #' @param span a peak is defined as an element in a sequence which is greater
@@ -213,33 +228,61 @@ cps_plot <- function(spct,
 #'   \code{character} strings "half.maximum" and "half.range" are also accepted
 #'   as arguments. A list with \code{numeric} and/or \code{character} values is
 #'   also accepted.
-#' @param annotations a character vector ("summaries" is ignored).
+#' @param annotations a character vector ("summaries" is ignored). For details
+#'   please see sections Plot Annotations and Title Annotations.
 #' @param time.format character Format as accepted by \code{\link[base]{strptime}}.
 #' @param tz character Time zone to use for title and/or subtitle.
-#' @param norm numeric normalization wavelength (nm) or character string "max"
-#'   for normalization at the wavelength of highest peak.
+#' @param norm numeric normalization wavelength (nm) or character string
+#'   \code{"max"} for normalization at the wavelength of highest peak or
+#'   \code{"skip"} for no change to exisitng normalization in \code{object}.
 #' @param text.size numeric size of text in the plot decorations.
 #' @param idfactor character Name of an index column in data holding a
 #'   \code{factor} with each spectrum in a long-form multispectrum object
 #'   corresponding to a distinct spectrum. If \code{idfactor=NULL} the name of
 #'   the factor is retrieved from metadata or if no metadata found, the
 #'   default "spct.idx" is tried.
+#' @param facets logical or integer Indicating if facets are to be created for
+#'   the levels of \code{idfactor} when \code{spct} contain multiple spectra in
+#'   long form.
 #' @param ylim numeric y axis limits,
 #' @param object.label character The name of the object being plotted.
 #' @param na.rm logical.
 #'
 #' @return a \code{ggplot} object.
 #'
+#' @seealso \code{\link[photobiology]{normalize}},
+#'   \code{\link[photobiology]{cps_spct}},
+#'   \code{\link[photobiology]{waveband}},
+#'   \code{\link[photobiologyWavebands]{photobiologyWavebands-package}} and
+#'   \code{\link[ggplot2]{autoplot}}
+#'
 #' @export
 #'
+#' @examples
+#'
+#' autoplot(white_led.cps_spct)
+#' autoplot(white_led.cps_spct, norm = "max")
+#' autoplot(white_led.cps_spct, annotations = "")
+#'
+#' two_leds.mspct <-
+#'   cps_mspct(list("LED 1" = white_led.cps_spct,
+#'                  "LED 2" = white_led.cps_spct / 2))
+#' autoplot(two_leds.mspct)
+#' autoplot(two_leds.mspct, idfactor = "Spectra")
+#' autoplot(two_leds.mspct, facets = 1) # one column
+#' autoplot(two_leds.mspct, facets = 2) # two columns
+#' autoplot(two_leds.mspct, plot.data = "mean")
+#'
 #' @family autoplot methods
 #'
 autoplot.cps_spct <-
-  function(object, ...,
+  function(object,
+           ...,
            w.band = getOption("photobiology.plot.bands",
                               default = list(UVC(), UVB(), UVA(), PAR())),
            range = NULL,
-           unit.out = "cps",
+           norm = "skip",
+           unit.out = NULL,
            pc.out = FALSE,
            label.qty = "mean",
            span = NULL,
@@ -247,17 +290,29 @@ autoplot.cps_spct <-
            annotations = NULL,
            time.format = "",
            tz = "UTC",
-           norm = NULL,
            text.size = 2.5,
            idfactor = NULL,
+           facets = FALSE,
            ylim = c(NA, NA),
            object.label = deparse(substitute(object)),
            na.rm = TRUE) {
+
+    force(object.label)
+
     annotations.default <-
       getOption("photobiology.plot.annotations",
                 default = c("boxes", "labels", "colour.guide", "peaks"))
     annotations <- decode_annotations(annotations,
                                       annotations.default)
+    # avoid warning in 'photobiology' (== 0.10.10)
+    if (is.character(norm) && norm == "update" && !is_normalized(object)) {
+      norm <- "skip"
+    }
+    # normalization skipping is handled by normalize()
+    object <- photobiology::normalize(x = object,
+                                      range = range,
+                                      norm = norm,
+                                      na.rm = na.rm)
     if (length(w.band) == 0) {
       if (is.null(range)) {
         w.band <- waveband(object)
@@ -268,22 +323,104 @@ autoplot.cps_spct <-
       }
     }
 
-    cps_plot(spct = object, w.band = w.band, range = range,
+    cps_plot(spct = object,
+             w.band = w.band,
+             range = range,
+             norm = norm,
+             pc.out = pc.out,
              label.qty = label.qty,
              span = span,
              wls.target = wls.target,
-             pc.out = pc.out,
-             annotations = annotations, norm = norm,
+             annotations = annotations,
              text.size = text.size,
              idfactor = idfactor,
+             facets = facets,
              ylim = ylim,
+             object.label = object.label,
              na.rm = na.rm,
              ...) +
       autotitle(object = object,
-                   time.format = time.format,
-                   tz = tz,
-                   object.label = object.label,
-                   annotations = annotations)
+                time.format = time.format,
+                tz = tz,
+                object.label = object.label,
+                annotations = annotations)
   }
 
+#' @rdname autoplot.cps_spct
+#'
+#' @param plot.data character Data to plot. Default is "as.is" plotting one line
+#'   per spectrum. When passing "mean", "median", "sum", "prod", "var", "sd",
+#'   "se" as argument all the spectra must contain data at the same wavelength
+#'   values.
+#'
+#' @export
+#'
+autoplot.cps_mspct <-
+  function(object,
+           ...,
+           range = NULL,
+           norm = "skip",
+           unit.out = NULL,
+           pc.out = FALSE,
+           idfactor = TRUE,
+           facets = FALSE,
+           plot.data = "as.is",
+           object.label = deparse(substitute(object)),
+           na.rm = TRUE) {
+
+    force(object.label)
+
+    idfactor <- validate_idfactor(idfactor = idfactor)
+    # We trim the spectra to avoid unnecesary computaions later
+    if (!is.null(range)) {
+      object <- photobiology::trim_wl(object,
+                                      range = range,
+                                      use.hinges = TRUE,
+                                      fill = NULL)
+    }
+    # We apply the normalization to the collection if it is to be bound
+    # otherwise normalization is applied to the "parallel-summary" spectrum
+    if (plot.data == "as.is") {
+      object <- photobiology::normalize(object,
+                                        range = NULL,
+                                        norm = norm,
+                                        na.rm = na.rm)
+      norm <- "skip"
+    }
+    # we convert the collection of spectra into a single spectrum object
+    # containing a summary spectrum or multiple spectra in long form.
+    z <- switch(plot.data,
+                as.is = photobiology::rbindspct(object, idfactor = idfactor),
+                mean = photobiology::s_mean(object),
+                median = photobiology::s_median(object),
+                sum = photobiology::s_sum(object),
+                prod = photobiology::s_prod(object),
+                var = photobiology::s_var(object),
+                sd = photobiology::s_sd(object),
+                se = photobiology::s_se(object)
+    )
+    if (is.cps_spct(z) && any(c("cps", "cps_1") %in% names(z))) {
+      autoplot(object = z,
+               range = NULL,
+               norm = norm,
+               pc.out = pc.out,
+               idfactor = idfactor,
+               facets = facets,
+               object.label = object.label,
+               na.rm = na.rm,
+               ...)
+    } else {
+      z <- as.generic_spct(z)
+      autoplot(object = z,
+               y.name = paste("cps", plot.data, sep = "."),
+               range = NULL,
+               norm = norm,
+               pc.out = pc.out,
+               idfactor = idfactor,
+               facets = facets,
+               object.label = object.label,
+               na.rm = na.rm,
+               ...)
+    }
+  }
 
