@@ -10,7 +10,8 @@
 #' @param w.band list of waveband objects.
 #' @param range an R object on which range() returns a vector of length 2, with
 #'   min annd max wavelengths (nm).
-#' @param pc.out logical, if TRUE use percents instead of fraction of one.
+#' @param pc.out logical, if TRUE use percent instead of fraction of one for
+#'   normalized spectral data.
 #' @param label.qty character string giving the type of summary quantity to use
 #'   for labels, one of "mean", "total", "contribution", and "relative".
 #' @param span a peak is defined as an element in a sequence which is greater
@@ -22,14 +23,15 @@
 #'   as arguments. A list with \code{numeric} and/or \code{character} values is
 #'   also accepted.
 #' @param annotations a character vector.
-#' @param norm numeric normalization wavelength (nm) or character string "max"
-#'   for normalization at the wavelength of highest peak.
 #' @param text.size numeric size of text in the plot decorations.
 #' @param idfactor character Name of an index column in data holding a
 #'   \code{factor} with each spectrum in a long-form multispectrum object
 #'   corresponding to a distinct spectrum. If \code{idfactor=NULL} the name of
 #'   the factor is retrieved from metadata or if no metadata found, the
 #'   default "spct.idx" is tried.
+#' @param facets logical or integer Indicating if facets are to be created for
+#'   the levels of \code{idfactor} when \code{spct} contain multiple spectra in
+#'   long form.
 #' @param na.rm logical.
 #' @param ylim numeric y axis limits,
 #' @param ... currently ignored.
@@ -46,9 +48,9 @@ e_rsp_plot <- function(spct,
                        span,
                        wls.target,
                        annotations,
-                       norm,
                        text.size,
                        idfactor,
+                       facets,
                        ylim,
                        na.rm,
                        ...) {
@@ -67,104 +69,66 @@ e_rsp_plot <- function(spct,
   }
 
   exposure.label <- NA
-  if (is.null(pc.out) || is.null(norm)) {
-    # no rescaling needed
-    if (is_normalized(spct) || is_scaled(spct)) {
-      s.rsp.label <- expression(Spectral~~energy~~response~~R[E](lambda)~~(relative~~units))
-      rsp.label.total <- "atop(R[E], (relative~~units))"
-      rsp.label.avg <- "atop(bar(R[E](lambda)), (relative~~units))"
-      scale.factor <- 1
-    } else {
-      time.unit <- getTimeUnit(spct)
-      if (!length(time.unit)) {
-        time.unit <- "unkonwn"
-      }
-      time.unit.char <- duration2character(time.unit)
-      if (time.unit.char=="second") {
-        s.rsp.label <- expression(Spectral~~energy~~response~~R[E](lambda)~~(resp.~~unit~~s^{-1}~nm^{-1}))
-        rsp.label.total  <- "atop(R[E], (resp.~~unit~~s^{-1}))"
-        rsp.label.avg  <- "atop(bar(R[E](lambda)), (resp.~~unit~~s^{-1}~nm^{-1}))"
-        scale.factor <- 1
-      } else if (time.unit.char=="day") {
-        s.rsp.label <- expression(Spectral~~energy~~response~~R[E](lambda)~~(resp.~~unit~~d^{-1}~nm^{-1}))
-        rsp.label.total  <- "atop(R[E], (resp.~~unit~~d^{-1}))"
-        rsp.label.avg  <- "atop(bar(R[E](lambda)), (resp.~~unit~~d^{-1}~nm^{-1}))"
-        scale.factor <- 1
-      } else if (time.unit.char=="hour") {
-        s.rsp.label <- expression(Spectral~~energy~~response~~R[E](lambda)~~(resp.~~unit~~h^{-1}~nm^{-1}))
-        rsp.label.total  <- "atop(R[E], (resp.~~unit~~h^{-1}))"
-        rsp.label.avg  <- "atop(bar(R[E](lambda)), (resp.~~unit~~h^{-1}~nm^{-1}))"
-        scale.factor <- 1
-      } else if (time.unit.char=="duration") {
-        s.rsp.label <- expression(Spectral~~energy~~response~~R[E](lambda)~~(resp.~~unit~nm^{-1}))
-        rsp.label.total  <- "atop(R[E], (resp.~~unit))"
-        rsp.label.avg  <- "atop(bar(R[E](lambda)), (resp.~~unit~nm^{-1}))"
-        exposure.label <- paste("Length of time:",
-                                ifelse(lubridate::is.duration(time.unit),
-                                       as.character(time.unit), "unknown"))
-        scale.factor <- 1
-      } else if (time.unit.char=="exposure") {
-        s.rsp.label <- expression(Spectral~~energy~~response~~R[E](lambda)~~(resp.~~unit~nm^{-1}))
-        rsp.label.total  <- "atop(R[E], (resp.~~unit))"
-        rsp.label.avg  <- "atop(bar(R[E](lambda)), (resp.~~unit~nm^{-1}))"
-        scale.factor <- 1
-      } else {
-        s.rsp.label <- expression(Spectral~~energy~~response~~R[E](lambda)~~(arbitrary~~units))
-        rsp.label.total <- "atop(R[E], (arbitrary~~units))"
-        rsp.label.avg <- "atop(bar(R[E](lambda)), (arbitrary~~units))"
-        scale.factor <- 1
-      }
-    }
-  } else {
-    # rescaling needed
-    if (!is.null(norm)) {
-      if (is.character(norm)) {
-        if (norm %in% c("max", "maximum")) {
-          idx <- which.max(spct[["s.e.response"]])
-        } else if (norm %in% c("min", "minimum")) {
-          idx <- which.min(spct[["s.e.response"]])
-        } else if (norm %in% c("mean", "average")) {
-          summary.value <- average_spct(spct)
-          idx <- "summary"
-        } else if (norm %in% c("total", "integral")) {
-          summary.value <- integrate_spct(spct)
-          idx <- "summary"
-        } else {
-          warning("Invalid character '", norm, "'value in 'norm'")
-          return(ggplot())
-        }
-        if (idx == "summary") {
-          scale.factor <- 1 / summary.value
-        } else {
-          scale.factor <- 1 / as.numeric(spct[idx, "s.e.response"])
-          norm <- as.numeric(spct[idx, "w.length"])
-        }
-      } else if (is.numeric(norm) && norm >= min(spct) && norm <= max(spct)) {
-        scale.factor <- 1 / interpolate_spct(spct, norm)[["s.e.response"]]
-      } else if (is.numeric(norm)) {
-        warning("'norm = ", norm, "' value outside spectral data range of ",
-                min(spct), " to ", round(max(spct)), " (nm)")
-        return(ggplot())
-      } else {
-        stop("'norm' should be numeric or character")
-      }
+
+  if (is_scaled(spct)) {
+    if (pc.out) {
+      warning("Percent scale supported only for normalized cps_spct objects.")
+      pc.out <- FALSE
     }
+    s.rsp.label <- expression(Spectral~~energy~~response~~k %*% R[E~lambda]~~("rel."))
+    rsp.label.total <- "atop(k %*% R[E], (\"rel.\"))"
+    rsp.label.avg <- "atop(bar(k %*% R[E~lambda]), (\"rel.\"))"
+  } else if (is_normalized(spct)) {
     if (!pc.out) {
       multiplier.label <- "rel."
-      #      scale.factor <- 1 * scale.factor
     } else {
       multiplier.label <- "%"
-      scale.factor <- 100 * scale.factor
-    }
-    if (is.numeric(norm)) {
-      norm <- signif(norm, digits = 4)
     }
+    norm.ls <- photobiology::getNormalization(spct)
+    norm.wl <- round(norm.ls[["norm.wl"]], digits = 1)
     s.rsp.label <-
-      bquote(Spectral~~energy~~response~~R[E]( italic(lambda) )/R[E]( .(norm))~~(.(multiplier.label)))
-    rsp.label.total  <- bquote(atop(integral(R[E](lambda), min, max), (.(multiplier.label))))
-    rsp.label.avg  <- bquote(atop(bar(R[E](lambda)/R[E](lambda = norm)), (.(multiplier.label))))
+      bquote(Spectral~~energy~~response~~R[E~lambda]/R[E~lambda==.(norm.wl)]~~(.(multiplier.label)))
+    rsp.label.total  <- bquote(atop(integral(R[E]/R[E~lambda==.(norm.wl)], min, max), (.(multiplier.label))))
+    rsp.label.avg  <- bquote(atop(bar(R[E~lambda]/R[E](lambda==.(norm.wl))), (.(multiplier.label))))
+  } else {
+    if (pc.out) {
+      warning("Percent scale supported only for normalized cps_spct objects.")
+      pc.out <- FALSE
+    }
+    time.unit <- getTimeUnit(spct)
+    if (!length(time.unit)) {
+      time.unit <- "unkonwn"
+    }
+    time.unit.char <- duration2character(time.unit)
+    if (time.unit.char=="second") {
+      s.rsp.label <- expression(Spectral~~energy~~response~~R[E~lambda]~~(resp.~~unit~~s^{-1}~nm^{-1}))
+      rsp.label.total  <- "atop(R[E], (resp.~~unit~~s^{-1}))"
+      rsp.label.avg  <- "atop(bar(R[E~lambda]), (resp.~~unit~~s^{-1}~nm^{-1}))"
+    } else if (time.unit.char=="day") {
+      s.rsp.label <- expression(Spectral~~energy~~response~~R[E~lambda]~~(resp.~~unit~~d^{-1}~nm^{-1}))
+      rsp.label.total  <- "atop(R[E], (resp.~~unit~~d^{-1}))"
+      rsp.label.avg  <- "atop(bar(R[E~lambda]), (resp.~~unit~~d^{-1}~nm^{-1}))"
+    } else if (time.unit.char=="hour") {
+      s.rsp.label <- expression(Spectral~~energy~~response~~R[E~lambda]~~(resp.~~unit~~h^{-1}~nm^{-1}))
+      rsp.label.total  <- "atop(R[E], (resp.~~unit~~h^{-1}))"
+      rsp.label.avg  <- "atop(bar(R[E~lambda]), (resp.~~unit~~h^{-1}~nm^{-1}))"
+    } else if (time.unit.char=="duration") {
+      s.rsp.label <- expression(Spectral~~energy~~response~~R[E~lambda]~~(resp.~~unit~nm^{-1}))
+      rsp.label.total  <- "atop(R[E], (resp.~~unit))"
+      rsp.label.avg  <- "atop(bar(R[E~lambda]), (resp.~~unit~nm^{-1}))"
+      exposure.label <- paste("Length of time:",
+                              ifelse(lubridate::is.duration(time.unit),
+                                     as.character(time.unit), "unknown"))
+    } else if (time.unit.char=="exposure") {
+      s.rsp.label <- expression(Spectral~~energy~~response~~R[E~lambda]~~(resp.~~unit~nm^{-1}))
+      rsp.label.total  <- "atop(R[E], (resp.~~unit))"
+      rsp.label.avg  <- "atop(bar(R[E~lambda]), (resp.~~unit~nm^{-1}))"
+    } else {
+      s.rsp.label <- expression(Spectral~~energy~~response~~R[E~lambda]~~(arbitrary~~units))
+      rsp.label.total <- "atop(R[E], (arbitrary~~units))"
+      rsp.label.avg <- "atop(bar(R[E~lambda]), (arbitrary~~units))"
+    }
   }
-  spct[["s.e.response"]] <- spct[["s.e.response"]] * scale.factor
 
   y.min <- ifelse(!is.na(ylim[1]),
                   ylim[1],
@@ -178,13 +142,13 @@ e_rsp_plot <- function(spct,
   } else if (label.qty %in% c("average", "mean")) {
     rsp.label <- "bar(R[E](lambda))"
   } else if (label.qty == "contribution") {
-    rsp.label <- "atop(Contribution~~to~~total, R[E]~~(fraction))"
+    rsp.label <- "atop(Contribution~~to~~total, R[E]~~(\"/1\"))"
   } else if (label.qty == "contribution.pc") {
-    rsp.label <- "atop(Contribution~~to~~total, R[E]~~(percent))"
+    rsp.label <- "atop(Contribution~~to~~total, R[E]~~(\"%\"))"
   } else if (label.qty == "relative") {
-    rsp.label <- "atop(Relative~~to~~sum, R[E]~~(fraction))"
+    rsp.label <- "atop(Relative~~to~~sum, R[E]~~(\"/1\"))"
   } else if (label.qty == "relative.pc") {
-    rsp.label <- "atop(Relative~~to~~sum, R[E]~~(percent))"
+    rsp.label <- "atop(Relative~~to~~sum, R[E]~~(\"%\"))"
   } else {
     rsp.label <- ""
   }
@@ -192,6 +156,7 @@ e_rsp_plot <- function(spct,
   plot <- ggplot(spct, aes_(~w.length, ~s.e.response))
   temp <- find_idfactor(spct = spct,
                         idfactor = idfactor,
+                        facets = facets,
                         annotations = annotations)
   plot <- plot + temp$ggplot_comp
   annotations <- temp$annotations
@@ -266,7 +231,8 @@ e_rsp_plot <- function(spct,
 #' @param w.band list of waveband objects.
 #' @param range an R object on which range() returns a vector of length 2, with
 #'   min annd max wavelengths (nm).
-#' @param pc.out logical, if TRUE use percents instead of fraction of one.
+#' @param pc.out logical, if TRUE use percent instead of fraction of one for
+#'   normalized spectral data.
 #' @param label.qty character string giving the type of summary quantity to use
 #'   for labels, one of "mean", "total", "contribution", and "relative".
 #' @param span a peak is defined as an element in a sequence which is greater
@@ -278,14 +244,15 @@ e_rsp_plot <- function(spct,
 #'   as arguments. A list with \code{numeric} and/or \code{character} values is
 #'   also accepted.
 #' @param annotations a character vector.
-#' @param norm numeric normalization wavelength (nm) or character string "max"
-#'   for normalization at the wavelength of highest peak.
 #' @param text.size numeric size of text in the plot decorations.
 #' @param idfactor character Name of an index column in data holding a
 #'   \code{factor} with each spectrum in a long-form multispectrum object
 #'   corresponding to a distinct spectrum. If \code{idfactor=NULL} the name of
 #'   the factor is retrieved from metadata or if no metadata found, the
 #'   default "spct.idx" is tried.
+#' @param facets logical or integer Indicating if facets are to be created for
+#'   the levels of \code{idfactor} when \code{spct} contain multiple spectra in
+#'   long form.
 #' @param ylim numeric y axis limits,
 #' @param na.rm logical.
 #' @param ... currently ignored.
@@ -302,9 +269,9 @@ q_rsp_plot <- function(spct,
                        span,
                        wls.target,
                        annotations,
-                       norm,
                        text.size,
                        idfactor,
+                       facets,
                        ylim,
                        na.rm,
                        ...) {
@@ -323,107 +290,66 @@ q_rsp_plot <- function(spct,
   }
 
   exposure.label <- NA
-  if (is.null(pc.out) || is.null(norm)) {
-    # no rescaling needed
-    if (is_normalized(spct) || is_scaled(spct)) {
-      s.rsp.label <- expression(Spectral~~photon~~response~~R[Q](lambda)~~(relative~~units))
-      rsp.label.total <- "atop(R[Q], (relative~~units))"
-      rsp.label.avg <- "atop(bar(R[Q](lambda)), (relative~~units))"
-      scale.factor <- 1
-    } else {
-      time.unit <- getTimeUnit(spct)
-      if (!length(time.unit)) {
-        time.unit <- "unkonwn"
-      }
-      time.unit.char <- duration2character(time.unit)
-      if (time.unit.char=="second") {
-        s.rsp.label <- expression(Spectral~~photon~~response~~R[Q](lambda)~~(resp.~~unit~~s^{-1}~nm^{-1}))
-        rsp.label.total  <- "atop(R[Q], (resp.~~unit~~s^{-1}))"
-        rsp.label.avg  <- "atop(bar(R[Q](lambda)), (resp.~~unit~~s^{-1}~nm^{-1}))"
-        scale.factor <- 1
-      } else if (time.unit.char=="day") {
-        s.rsp.label <- expression(Spectral~~photon~~response~~R[Q](lambda)~~(resp.~~unit~~d^{-1}~nm^{-1}))
-        rsp.label.total  <- "atop(R[Q], (resp.~~unit~~d^{-1}))"
-        rsp.label.avg  <- "atop(bar(R[Q](lambda)), (resp.~~unit~~d^{-1}~nm^{-1}))"
-        scale.factor <- 1
-      } else if (time.unit.char=="hour") {
-        s.rsp.label <- expression(Spectral~~photon~~response~~R[Q](lambda)~~(resp.~~unit~~h^{-1}~nm^{-1}))
-        rsp.label.total  <- "atop(R[Q], (resp.~~unit~~h^{-1}))"
-        rsp.label.avg  <- "atop(bar(R[Q](lambda)), (resp.~~unit~~h^{-1}~nm^{-1}))"
-        scale.factor <- 1
-      } else if (time.unit.char=="duration") {
-        s.rsp.label <- expression(Spectral~~photon~~response~~R[Q](lambda)~~(resp.~~unit~nm^{-1}))
-        rsp.label.total  <- "atop(R[Q], (resp.~~unit))"
-        rsp.label.avg  <- "atop(bar(R[Q](lambda)), (resp.~~unit~nm^{-1}))"
-        exposure.label <- paste("Length of time:",
-                                ifelse(lubridate::is.duration(time.unit),
-                                       as.character(time.unit), "unknown"))
-        scale.factor <- 1
-      } else if (time.unit.char=="exposure") {
-        s.rsp.label <- expression(Spectral~~photon~~response~~R[Q](lambda)~~(resp.~~unit~nm^{-1}))
-        rsp.label.total  <- "atop(R[Q], (resp.~~unit))"
-        rsp.label.avg  <- "atop(bar(R[Q](lambda)), (resp.~~unit~nm^{-1}))"
-        exposure.label <- paste("Length of time:",
-                                ifelse(lubridate::is.duration(time.unit),
-                                       as.character(time.unit), "unknown"))
-        scale.factor <- 1
-      } else {
-        s.rsp.label <- expression(Spectral~~photon~~response~~R[Q](lambda)~~(arbitrary~~units))
-        rsp.label.total <- "atop(R[Q], (arbitrary~~units))"
-        rsp.label.avg <- "atop(bar(R[Q](lambda)), (arbitrary~~units))"
-        scale.factor <- 1
-      }
-    }
-  } else {
-    # rescaling needed
-    if (!is.null(norm)) {
-      if (is.character(norm)) {
-        if (norm %in% c("max", "maximum")) {
-          idx <- which.max(spct[["s.q.response"]])
-        } else if (norm %in% c("min", "minimum")) {
-          idx <- which.min(spct[["s.q.response"]])
-        } else if (norm %in% c("mean", "average")) {
-          summary.value <- average_spct(spct)
-          idx <- "summary"
-        } else if (norm %in% c("total", "integral")) {
-          summary.value <- integrate_spct(spct)
-          idx <- "summary"
-        } else {
-          warning("Invalid character '", norm, "'value in 'norm'")
-          return(ggplot())
-        }
-        if (idx == "summary") {
-          scale.factor <- 1 / summary.value
-        } else {
-          scale.factor <- 1 / as.numeric(spct[idx, "s.q.response"])
-          norm <- as.numeric(spct[idx, "w.length"])
-        }
-      } else if (is.numeric(norm) && norm >= min(spct) && norm <= max(spct)) {
-        scale.factor <- 1 / interpolate_spct(spct, norm)$s.q.response
-      } else if (is.numeric(norm)) {
-        warning("'norm = ", norm, "' value outside spectral data range of ",
-                min(spct), " to ", round(max(spct)), " (nm)")
-        return(ggplot())
-      } else {
-        stop("'norm' should be numeric or character")
-      }
+
+  if (is_scaled(spct)) {
+    if (pc.out) {
+      warning("Percent scale supported only for normalized cps_spct objects.")
+      pc.out <- FALSE
     }
+    s.rsp.label <- expression(Spectral~~photon~~response~~k %*% R[Q~lambda]~~("rel."))
+    rsp.label.total <- "atop(k %*% R[Q], (\"rel.\"))"
+    rsp.label.avg <- "atop(bar(k %*% R[Q~lambda]), (\"rel.\"))"
+  } else if (is_normalized(spct)) {
     if (!pc.out) {
       multiplier.label <- "rel."
-      #      scale.factor <- 1 * scale.factor
-    } else {
+     } else {
       multiplier.label <- "%"
-      scale.factor <- 100 * scale.factor
     }
-    if (is.numeric(norm)) {
-      norm <- signif(norm, digits = 4)
+    norm.ls <- photobiology::getNormalization(spct)
+      norm.wl <- round(norm.ls[["norm.wl"]], digits = 1)
+      s.rsp.label <-
+        bquote(Spectral~~photon~~response~~R[Q~lambda]/R[Q~lambda==.(norm.wl)]~~(.(multiplier.label)))
+      rsp.label.total  <- bquote(atop(integral(R[Q~lambda], min, max), (.(multiplier.label))))
+      rsp.label.avg  <- bquote(atop(bar(R[Q~lambda]/R[Q~lambda==.(norm.wl)]), (.(multiplier.label))))
+  } else {
+    if (pc.out) {
+      warning("Percent scale supported only for normalized cps_spct objects.")
+      pc.out <- FALSE
+    }
+    time.unit <- getTimeUnit(spct)
+    if (!length(time.unit)) {
+      time.unit <- "unkonwn"
+    }
+    time.unit.char <- duration2character(time.unit)
+    if (time.unit.char=="second") {
+      s.rsp.label <- expression(Spectral~~photon~~response~~R[Q~lambda]~~(resp.~~unit~~s^{-1}~nm^{-1}))
+      rsp.label.total  <- "atop(R[Q], (resp.~~unit~~s^{-1}))"
+      rsp.label.avg  <- "atop(bar(R[Q~lambda]), (resp.~~unit~~s^{-1}~nm^{-1}))"
+    } else if (time.unit.char=="day") {
+      s.rsp.label <- expression(Spectral~~photon~~response~~R[Q~lambda]~~(resp.~~unit~~d^{-1}~nm^{-1}))
+      rsp.label.total  <- "atop(R[Q], (resp.~~unit~~d^{-1}))"
+      rsp.label.avg  <- "atop(bar(R[Q~lambda]), (resp.~~unit~~d^{-1}~nm^{-1}))"
+    } else if (time.unit.char=="hour") {
+      s.rsp.label <- expression(Spectral~~photon~~response~~R[Q~lambda]~~(resp.~~unit~~h^{-1}~nm^{-1}))
+      rsp.label.total  <- "atop(R[Q], (resp.~~unit~~h^{-1}))"
+      rsp.label.avg  <- "atop(bar(R[Q~lambda]), (resp.~~unit~~h^{-1}~nm^{-1}))"
+    } else if (time.unit.char=="duration") {
+      s.rsp.label <- expression(Spectral~~photon~~response~~R[Q~lambda]~~(resp.~~unit~nm^{-1}))
+      rsp.label.total  <- "atop(R[Q], (resp.~~unit))"
+      rsp.label.avg  <- "atop(bar(R[Q~lambda]), (resp.~~unit~nm^{-1}))"
+      exposure.label <- paste("Length of time:",
+                              ifelse(lubridate::is.duration(time.unit),
+                                     as.character(time.unit), "unknown"))
+    } else if (time.unit.char=="exposure") {
+      s.rsp.label <- expression(Spectral~~photon~~response~~R[Q~lambda]~~(resp.~~unit~nm^{-1}))
+      rsp.label.total  <- "atop(R[Q], (resp.~~unit))"
+      rsp.label.avg  <- "atop(bar(R[Q~lambda]), (resp.~~unit~nm^{-1}))"
+    } else {
+      s.rsp.label <- expression(Spectral~~photon~~response~~R[Q~lambda]~~(arbitrary~~units))
+      rsp.label.total <- "atop(R[Q], (arbitrary~~units))"
+      rsp.label.avg <- "atop(bar(R[Q~lambda]), (arbitrary~~units))"
     }
-    s.rsp.label <-
-      bquote(Spectral~~photon~~response~~R[Q]( italic(lambda) )/R[Q]( .(norm))~~(.(multiplier.label)))
-    rsp.label.total  <- bquote(atop(integral(R[Q](lambda), min, max), (.(multiplier.label))))
-    rsp.label.avg  <- bquote(atop(bar(R[Q](lambda)/R[Q](lambda = norm)), (.(multiplier.label))))
   }
-  spct[["s.q.response"]] <- spct[["s.q.response"]] * scale.factor
 
   y.min <- ifelse(!is.na(ylim[1]),
                   ylim[1],
@@ -437,13 +363,13 @@ q_rsp_plot <- function(spct,
   } else if (label.qty %in% c("average", "mean")) {
     rsp.label <- "bar(R[Q](lambda))"
   } else if (label.qty == "contribution") {
-    rsp.label <- "atop(Contribution~~to~~total, R[Q]~~(fraction))"
+    rsp.label <- "atop(Contribution~~to~~total, R[Q]~~(\"/1\"))"
   } else if (label.qty == "contribution.pc") {
-    rsp.label <- "atop(Contribution~~to~~total, R[Q]~~(percent))"
+    rsp.label <- "atop(Contribution~~to~~total, R[Q]~~(\"%\"))"
   } else if (label.qty == "relative") {
-    rsp.label <- "atop(Relative~~to~~sum, R[Q]~~(fraction))"
+    rsp.label <- "atop(Relative~~to~~sum, R[Q]~~(\"/1\"))"
   } else if (label.qty == "relative.pc") {
-    rsp.label <- "atop(Relative~~to~~sum, R[Q]~~(percent))"
+    rsp.label <- "atop(Relative~~to~~sum, R[Q]~~(\"%\"))"
   } else {
     rsp.label <- ""
   }
@@ -451,6 +377,7 @@ q_rsp_plot <- function(spct,
   plot <- ggplot(spct, aes_(x = ~w.length, y = ~s.q.response))
   temp <- find_idfactor(spct = spct,
                         idfactor = idfactor,
+                        facets = facets,
                         annotations = annotations)
   plot <- plot + temp$ggplot_comp
   annotations <- temp$annotations
@@ -494,6 +421,12 @@ q_rsp_plot <- function(spct,
                              na.rm = TRUE )
   }
 
+  if (abs(y.max - 1) < 0.02 && abs(y.min) < 0.02) {
+    y.breaks <- c(0, 0.25, 0.5, 0.75, 1)
+  } else {
+    y.breaks <- scales::pretty_breaks(n = 5)
+  }
+
   if (!is.null(annotations) &&
       length(intersect(c("boxes", "segments", "labels", "summaries",
                          "colour.guide", "reserve.space"), annotations)) > 0L) {
@@ -504,11 +437,15 @@ q_rsp_plot <- function(spct,
     x.limits <- range(spct)
   }
 
-  if ((abs(y.min) < 5e-2) && (abs(y.max - 1) < 5.e-2)) {
+  if (pc.out) {
     plot <- plot +
-      scale_y_continuous(breaks = c(0, 0.25, 0.5, 0.75, 1), limits = y.limits)
+      scale_y_continuous(labels = scales::percent,
+                         breaks = y.breaks,
+                         limits = y.limits)
   } else {
-    plot <- plot + scale_y_continuous(limits = y.limits)
+    plot <-
+      plot + scale_y_continuous(breaks = y.breaks,
+                                limits = y.limits)
   }
   plot + scale_x_continuous(limits = x.limits, breaks = scales::pretty_breaks(n = 7))
 }
@@ -518,9 +455,12 @@ q_rsp_plot <- function(spct,
 #' These methods return a ggplot object with an annotated plot of a
 #' response_spct object or of the spectra contained in a response_mspct object.
 #'
-#' @note Note that scales are expanded so as to make space for the annotations.
-#'   The object returned is a ggplot object, and can be further manipulated and
-#'   added to.
+#' Note that scales are expanded so as to make space for the annotations. The
+#' object returned is a ggplot object, and can be further manipulated and added
+#' to.
+#'
+#' @inheritSection decoration Plot Annotations
+#' @inheritSection autotitle Title Annotations
 #'
 #' @param object a response_spct object or a response_mspct object.
 #' @param ... in the case of collections of spectra, additional arguments passed
@@ -528,9 +468,15 @@ q_rsp_plot <- function(spct,
 #' @param w.band a single waveband object or a list of waveband objects.
 #' @param range an R object on which range() returns a vector of length 2, with
 #'   min annd max wavelengths (nm).
+#' @param norm numeric Normalization wavelength (nm) or character string "max",
+#'   or "min" for normalization at the corresponding wavelength, "update" to
+#'   update the normalization after modifying units of expression, quantity
+#'   or range but respecting the previously used criterion, or "skip" to force
+#'   return of \code{object} unchanged.
 #' @param unit.out character string indicating type of radiation units to use
 #'   for plotting: "photon" or its synomin "quantum", or "energy".
-#' @param pc.out logical, if TRUE use percents instead of fraction of one
+#' @param pc.out logical, if TRUE use percent instead of fraction of one for
+#'   normalized spectral data.
 #' @param label.qty character string giving the type of summary quantity to use
 #'   for labels, one of "mean", "total", "contribution", and "relative".
 #' @param span a peak is defined as an element in a sequence which is greater
@@ -541,7 +487,8 @@ q_rsp_plot <- function(spct,
 #'   \code{character} strings "half.maximum" and "half.range" are also accepted
 #'   as arguments. A list with \code{numeric} and/or \code{character} values is
 #'   also accepted.
-#' @param annotations a character vector.
+#' @param annotations a character vector. For details please see sections Plot
+#'   Annotations and Title Annotations.
 #' @param time.format character Format as accepted by
 #'   \code{\link[base]{strptime}}.
 #' @param tz character Time zone to use for title and/or subtitle.
@@ -554,6 +501,9 @@ q_rsp_plot <- function(spct,
 #'   corresponding to a distinct spectrum. If \code{idfactor=NULL} the name of
 #'   the factor is retrieved from metadata or if no metadata found, the
 #'   default "spct.idx" is tried.
+#' @param facets logical or integer Indicating if facets are to be created for
+#'   the levels of \code{idfactor} when \code{spct} contain multiple spectra in
+#'   long form.
 #' @param ylim numeric y axis limits,
 #' @param object.label character The name of the object being plotted.
 #' @param na.rm logical.
@@ -562,12 +512,26 @@ q_rsp_plot <- function(spct,
 #'
 #' @export
 #'
-#' @keywords hplot
+#' @seealso \code{\link[photobiology]{normalize}},
+#'   \code{\link[photobiology]{response_spct}},
+#'   \code{\link[photobiology]{waveband}},
+#'   \code{\link[photobiologyWavebands]{photobiologyWavebands-package}} and
+#'   \code{\link[ggplot2]{autoplot}}
 #'
 #' @examples
 #'
 #' autoplot(photodiode.spct)
 #' autoplot(photodiode.spct, unit.out = "photon")
+#' autoplot(photodiode.spct, annotations = "")
+#' autoplot(photodiode.spct, norm = "skip")
+#' autoplot(photodiode.spct, norm = 400)
+#'
+#' two_sensors.mspct <-
+#'  response_mspct(list("Photodiode" = photodiode.spct,
+#'                      "Coupled charge device" = ccd.spct))
+#' autoplot(two_sensors.mspct, normalize = TRUE, unit.out = "photon")
+#' autoplot(two_sensors.mspct, normalize = TRUE, idfactor = "Spectra")
+#' autoplot(two_sensors.mspct, normalize = TRUE, facets = 2)
 #'
 #' @family autoplot methods
 #'
@@ -576,7 +540,10 @@ autoplot.response_spct <-
            w.band = getOption("photobiology.plot.bands",
                               default = list(UVC(), UVB(), UVA(), PAR())),
            range = NULL,
-           unit.out = getOption("photobiology.radiation.unit", default="energy"),
+           norm = getOption("ggspectra.norm",
+                            default = "max"),
+           unit.out = getOption("photobiology.radiation.unit",
+                                default = "energy"),
            pc.out = FALSE,
            label.qty = NULL,
            span = NULL,
@@ -584,19 +551,33 @@ autoplot.response_spct <-
            annotations = NULL,
            time.format = "",
            tz = "UTC",
-           norm = "max",
            text.size = 2.5,
            idfactor = NULL,
+           facets = FALSE,
            ylim = c(NA, NA),
            object.label = deparse(substitute(object)),
            na.rm = TRUE) {
+
+    force(object.label)
+
     annotations.default <-
       getOption("photobiology.plot.annotations",
                 default = c("boxes", "labels", "summaries", "colour.guide", "peaks"))
     annotations <- decode_annotations(annotations,
                                       annotations.default)
+    # avoid warning in 'photobiology' (== 0.10.10)
+    if (is.character(norm) && norm == "update" && !is_normalized(object)) {
+      norm <- "skip"
+    }
+    # normalization needs to be redone if unit.out has changed
+    object <- photobiology::normalize(x = object,
+                                      range = range,
+                                      norm = norm,
+                                      unit.out = unit.out,
+                                      na.rm = na.rm)
     if (is.null(label.qty)) {
-      if (is_normalized(object) || is_scaled(object)) {
+      if (photobiology::is_normalized(object) ||
+          photobiology::is_scaled(object)) {
         label.qty = "contribution"
       } else {
         label.qty = "total"
@@ -604,11 +585,11 @@ autoplot.response_spct <-
     }
     if (length(w.band) == 0) {
       if (is.null(range)) {
-        w.band <- waveband(object)
-      } else if (is.waveband(range)) {
+        w.band <- photobiology::waveband(object)
+      } else if (photobiology::is.waveband(range)) {
         w.band <- range
       } else {
-        w.band <-  waveband(range, wb.name = "Total")
+        w.band <- photobiology::waveband(range, wb.name = "Total")
       }
     }
 
@@ -621,9 +602,10 @@ autoplot.response_spct <-
                                span = span,
                                wls.target = wls.target,
                                annotations = annotations,
-                               norm = norm,
+                               norm = norm,              # read from object
                                text.size = text.size,
                                idfactor = idfactor,
+                               facets = facets,
                                ylim = ylim,
                                na.rm = na.rm,
                                ...)
@@ -638,41 +620,103 @@ autoplot.response_spct <-
                                annotations = annotations, norm = norm,
                                text.size = text.size,
                                idfactor = idfactor,
+                               facets = facets,
                                ylim = ylim,
                                na.rm = na.rm,
                                ...)
     } else {
-      stop("Invalid 'unit.out' argument value: '", unit.out, "'")
+      stop("Invalid 'unit.out' argument: '", unit.out, "'")
     }
     out.ggplot +
       autotitle(object = object,
-                   time.format = time.format,
-                   tz = tz,
-                   object.label = object.label,
-                   annotations = annotations)
+                time.format = time.format,
+                tz = tz,
+                object.label = object.label,
+                annotations = annotations)
   }
 
 #' @rdname autoplot.response_spct
 #'
-#' @param plot.data character Data to plot. Default is "as.is" plotting
-#'   one line per spectrum. When passing "mean" or "median" as
-#'   argument all the spectra must contain data at the same wavelength values.
+#' @param plot.data character Data to plot. Default is "as.is" plotting one line
+#'   per spectrum. When passing "mean", "median", "sum", "prod", "var", "sd",
+#'   "se" as argument all the spectra must contain data at the same wavelength
+#'   values.
 #'
 #' @export
 #'
 autoplot.response_mspct <-
-  function(object, ..., range = NULL, plot.data = "as.is") {
-    # We trim the spectra to avoid unnecesary computaions later
+  function(object,
+           ...,
+           range = NULL,
+           norm = getOption("ggspectra.norm",
+                            default = "max"),
+           unit.out = getOption("photobiology.radiation.unit", default="energy"),
+           pc.out = FALSE,
+           plot.data = "as.is",
+           facets = FALSE,
+           idfactor = TRUE,
+           object.label = deparse(substitute(object)),
+           na.rm = TRUE) {
+
+    force(object.label)
+
+    idfactor <- validate_idfactor(idfactor = idfactor)
+    # We trim the spectra to avoid unnecessary computations later
     if (!is.null(range)) {
-      object <- trim_wl(object, range = range, use.hinges = TRUE, fill = NULL)
+      object <- photobiology::trim_wl(object,
+                                      range = range,
+                                      use.hinges = TRUE,
+                                      fill = NULL)
     }
+    # We apply the normalization to the collection if it is to be bound
+    # otherwise normalization is applied to the "parallel-summary" spectrum
+    if (plot.data == "as.is") {
+      object <- photobiology::normalize(object,
+                                        norm = norm,
+                                        unit.out = unit.out,
+                                        na.rm = na.rm)
+      norm <- "skip"
+    }
+    # we ensure the units are correct
+    object <- switch(unit.out,
+                     photon = e2q(object, action = "replace"),
+                     energy = q2e(object, action = "replace"))
     # we convert the collection of spectra into a single spectrum object
     # containing a summary spectrum or multiple spectra in long form.
     z <- switch(plot.data,
+                as.is = photobiology::rbindspct(object, idfactor = idfactor),
                 mean = photobiology::s_mean(object),
                 median = photobiology::s_median(object),
-                as.is = photobiology::rbindspct(object)
+                sum = photobiology::s_sum(object),
+                prod = photobiology::s_prod(object),
+                var = photobiology::s_var(object),
+                sd = photobiology::s_sd(object),
+                se = photobiology::s_se(object)
     )
-    autoplot(object = z, range = NULL, ...)
+    col.name <- c(photon = "s.q.response", energy = "s.e.response")
+    if (is.response_spct(z) && any(col.name %in% names(z))) {
+      autoplot(object = z,
+               range = NULL,
+               norm = norm,
+               unit.out = unit.out,
+               pc.out = pc.out,
+               facets = facets,
+               idfactor = idfactor,
+               object.label = object.label,
+               na.rm = na.rm,
+               ...)
+    } else {
+      z <- as.generic_spct(z)
+      autoplot(object = z,
+               y.name = paste(col.name[unit.out], plot.data, sep = "."),
+               range = NULL,
+               norm = norm,
+               pc.out = pc.out,
+               facets = facets,
+               idfactor = idfactor,
+               object.label = object.label,
+               na.rm = na.rm,
+               ...)
+    }
   }
 
