@@ -87,10 +87,11 @@ StatColor <-
     compute_group = function(data,
                              scales,
                              chroma.type) {
-      dplyr::mutate(data,
-                    wl.color = photobiology::fast_color_of_wl(x, chroma.type = chroma.type))
+      data[["wl.color"]] <-
+        photobiology::fast_color_of_wl(data[["x"]], chroma.type = chroma.type)
+      data
     },
-    default_aes = ggplot2::aes(color = ..wl.color..,
-                               fill = ..wl.color..),
+    default_aes = ggplot2::aes(color = after_stat(wl.color),
+                               fill = after_stat(wl.color)),
     required_aes = c("x", "y")
   )
